//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'https://cecill.info'.

function [tdb_tt] = CL__dat_tt2tdb(cjd_tt)
// TT to TDB conversion
//
// Calling Sequence
// tdb_tt = CL__dat_tt2tdb(cjd_tt)
//
// Description
// <itemizedlist><listitem>
// <p>Converts the time of a modified Julian date (from 1950.0) from TT time scale to 
// TDB time scale.</p>
// <p>By definition : TDB = TT + CL__dat_tt2tdb(TT) </p>
// <p>The amplitude of TDB-TT is less than 2 milliseconds </p>
// </listitem>
// </itemizedlist>
//
// Parameters
// cjd_tt: Modified (1950.0) Julian date in TT time scale. (2xN)
// tdb_tt: TDB minus TT = number of seconds to be added to cjd_tt to get cjd_tdb. (1xN)
//
// Authors
// CNES - DCT/SB
//
// See also
// CL__dat_tdb_tt
//
// Examples
// cjd_tt = CL_dat_cal2cjd(2000,1,1,12,0,0);
// tdb_tt = CL__dat_tt2tdb(cjd_tt);

// Declarations:

// Code:

// -----------------------------------------------------------------
// Version 1
// The definition is identical to that in "Patrius" CNES library. 
// The accuracy is about 40 micro seconds. 
// The definition is consistent with SPICE to about 1 micro second. 
// -----------------------------------------------------------------
function [tdb_tt] = dat__tdb_tt_v1(cjd_tt); 

  // Days from J2000 epoch (TT time scale) 
  delta_t = (cjd_tt(1,:) - 18262) + (cjd_tt(2,:) - 0.5); 

  g = (357.53 + 0.9856003 * delta_t) * %pi / 180; // rad 

  tdb_tt = 0.001658 * sin(g) + 0.000014 * sin(2*g); 
endfunction


// -----------------------------------------------------------------
// Version 2
// accuracy is ~10 microseconds in the year range 1600 - 2200 
// Reference: 
// http://aa.usno.navy.mil/publications/docs/Circular_179.pdf
// 
// Coefficients are ~the same as in Fairhead / bretagnon: 
// "An analytical formula for the time transformation TB-TT"
// Astronomy and Astrophysics · February 1990
// -----------------------------------------------------------------
//function [tdb_tt] = dat__tdb_tt_v2(cjd_tt)
//
//  // T : number of centuries since J2000
//    T = (cjd_tt(1,:) - 18262) + (cjd_tt(2,:) - 0.5); 
//
//  tdb_tt = 0.001657 * sin(628.3076 * T + 6.2401) + ...
//           0.000022 * sin(575.3385 * T + 4.2970) + ...
//	       0.000014 * sin(1256.6152 * T + 6.1969) + ... 
//	       0.000005 * sin(606.9777 * T + 4.0212) + ...
//	       0.000005 * sin(52.9691 * T + 0.4444) + ...
//	       0.000002 * sin(21.3299 * T + 5.5431) + ...
//	       0.000010 * T .* sin(628.3076 * T + 4.2490); 
//  
//endfunction 


// MAIN

// use most simple expression (though less precise) 
tdb_tt = dat__tdb_tt_v1(cjd_tt); 


endfunction
